/**
 * <a href="http://www.openolat.org">
 * OpenOLAT - Online Learning and Training</a><br>
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License"); <br>
 * you may not use this file except in compliance with the License.<br>
 * You may obtain a copy of the License at the
 * <a href="http://www.apache.org/licenses/LICENSE-2.0">Apache homepage</a>
 * <p>
 * Unless required by applicable law or agreed to in writing,<br>
 * software distributed under the License is distributed on an "AS IS" BASIS, <br>
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. <br>
 * See the License for the specific language governing permissions and <br>
 * limitations under the License.
 * <p>
 * Original Author:
 * Daniel Haag <at> uibk.ac.at
 * <p>
 */
package org.olat.course.export;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.olat.course.export.CourseEnvironmentMapper;

/**
 * This subclass of CourseEnvironmentMapper is used when only a node subset is mapped
 * resulting in new node identifiers for the nodes as they might be imported into a new
 * course multiple times.
 * 
 * @author Daniel Haag
 */
public class CourseFragmentEnvironmentMapper extends CourseEnvironmentMapper {

	private Map<String,String> courseNodeIdentMap;

	public CourseFragmentEnvironmentMapper() {
		super();
		courseNodeIdentMap = new HashMap<>();
	}
	
	public void addNodeIdentKeyPair(String sourceIdent, String targetIdent) {
		courseNodeIdentMap.put(sourceIdent, targetIdent);
	}
	
	public String getNodeTargetIdent(String sourceIdent) {
		return courseNodeIdentMap.get(sourceIdent);
	}
	
	public Set<String> getNodeSourceIds() {
		return courseNodeIdentMap.keySet();
	}
}
